@@ -95,10 +95,8 @@ class GaussianField:
 
 class KLExpansion:
     """
-    KLExpansion: Computes the 1D KL expansion of the covariance matrix C, using the
-       Legendre-Gauss-Loabatto rule for the solution to the generalized eigenvalue 
-       problem A * u = lmb * M * u
-    The KLExpansion of d-dimensional random fields is obtained by tensor product
+    KLExpansion: Computes the 1D KL expansion of the covariance matrix C, using the Legendre-Gauss-Loabatto rule for the solution to the generalized eigenvalue problem A * u = lmb * M * u.
+    The KLExpansion of d-dimensional random fields is obtained by tensor product.
 
     :param function C: Covariance function C(x1,x2)
     :param int d: dimension of the tensorized field
